Package: rang
Title: Reconstructing Reproducible R Computational Environments
Version: 0.3.0
Authors@R: 
    c(person("Chung-hong", "Chan", , "chainsawtiney@gmail.com", role = c("aut", "cre"),
           comment = c(ORCID = "0000-0002-6232-7530")),
      person("David", "Schoch", , "david@schochastics.net", role = "aut", 
           comment = c(ORCID = "0000-0003-2952-4812")),
      person("Egor", "Kotov", , "kotov.egor@gmail.com", role = "ctb",
           comment = c(ORCID = "0000-0001-6690-5345")))
Description: Resolve the dependency graph of R packages at a specific time point based on the information from various 'R-hub' web services <https://blog.r-hub.io/>. The dependency graph can then be used to reconstruct the R computational environment with 'Rocker' <https://rocker-project.org>.
License: GPL (>= 3)
Encoding: UTF-8
RoxygenNote: 7.2.3
URL: https://github.com/gesistsa/rang
BugReports: https://github.com/gesistsa/rang/issues
Suggests: knitr, rmarkdown, testthat (>= 3.0.0)
Config/testthat/edition: 3
Imports: parsedate, fastmap, jsonlite, memoise, pkgsearch, remotes,
        utils, httr, vctrs, renv, here
Depends: R (>= 3.5.0)
VignetteBuilder: knitr
LazyData: true
NeedsCompilation: no
Packaged: 2023-10-08 13:29:24 UTC; chainsawriot
Author: Chung-hong Chan [aut, cre] (<https://orcid.org/0000-0002-6232-7530>),
  David Schoch [aut] (<https://orcid.org/0000-0003-2952-4812>),
  Egor Kotov [ctb] (<https://orcid.org/0000-0001-6690-5345>)
Maintainer: Chung-hong Chan <chainsawtiney@gmail.com>
Repository: CRAN
Date/Publication: 2023-10-08 14:50:02 UTC
Built: R 4.6.0; ; 2026-04-26 09:46:31 UTC; unix
