# Generated by roxygen2: do not edit by hand

S3method(as_pkgrefs,character)
S3method(as_pkgrefs,default)
S3method(as_pkgrefs,sessionInfo)
S3method(convert_edgelist,default)
S3method(convert_edgelist,rang)
S3method(convert_edgelist,ranglet)
S3method(print,rang)
S3method(print,ranglet)
export(apptainerise)
export(apptainerise_rang)
export(apptainerize)
export(apptainerize_rang)
export(as_pkgrefs)
export(convert_edgelist)
export(create_turing)
export(dockerise)
export(dockerise_rang)
export(dockerize)
export(dockerize_rang)
export(export_rang)
export(export_renv)
export(generate_installation_order)
export(query_sysreqs)
export(resolve)
export(singularise)
export(singularise_rang)
export(singularize)
export(singularize_rang)
export(use_rang)
importFrom(here,here)
importFrom(memoise,memoise)
importFrom(pkgsearch,cran_package_history)
importFrom(remotes,system_requirements)
importFrom(utils,download.file)
